Learn R Programming

paws.customer.engagement (version 0.1.11)

connect_associate_lex_bot: This API is in preview release for Amazon Connect and is subject to change

Description

This API is in preview release for Amazon Connect and is subject to change.

Allows the specified Amazon Connect instance to access the specified Amazon Lex bot.

Usage

connect_associate_lex_bot(InstanceId, LexBot)

Arguments

InstanceId

[required] The identifier of the Amazon Connect instance.

LexBot

[required] The Amazon Lex box to associate with the instance.

Value

An empty list.

Request syntax

svc$associate_lex_bot(
  InstanceId = "string",
  LexBot = list(
    Name = "string",
    LexRegion = "string"
  )
)