Creates a flow for the specified Amazon Connect instance.
See https://www.paws-r-sdk.com/docs/connect_create_contact_flow/ for full documentation.
connect_create_contact_flow(
InstanceId,
Name,
Type,
Description = NULL,
Content,
Status = NULL,
Tags = NULL
)[required] The identifier of the Amazon Connect instance.
[required] The name of the flow.
[required] The type of the flow. For descriptions of the available types, see Choose a flow type in the Amazon Connect Administrator Guide.
The description of the flow.
[required] The JSON string that represents the content of the flow. For an example, see Example flow in Amazon Connect Flow language.
Length Constraints: Minimum length of 1. Maximum length of 256000.
Indicates the flow status as either SAVED or PUBLISHED. The
PUBLISHED status will initiate validation on the content. the SAVED
status does not initiate validation of the content. SAVED |
PUBLISHED.
The tags used to organize, track, or control access for this resource. For example, { "Tags": {"key1":"value1", "key2":"value2"} }.