This API is in preview release for Amazon Connect and is subject to change.
Creates a use case for an AppIntegration association.
connect_create_use_case(InstanceId, IntegrationAssociationId,
UseCaseType)[required] The identifier of the Amazon Connect instance.
[required] The identifier for the AppIntegration association.
[required] The type of use case to associate to the AppIntegration association. Each AppIntegration association can have only one of each use case type.
A list with the following syntax:
list( UseCaseId = "string", UseCaseArn = "string" )
svc$create_use_case( InstanceId = "string", IntegrationAssociationId = "string", UseCaseType = "RULES_EVALUATION" )