This API is in preview release for Amazon Connect and is subject to change.
Removes the storage type configurations for the specified resource type and association ID.
connect_disassociate_instance_storage_config(InstanceId, AssociationId,
ResourceType)[required] The identifier of the Amazon Connect instance.
[required] The existing association identifier that uniquely identifies the resource type and storage config for the given instance ID.
[required] A valid resource type.
An empty list.
svc$disassociate_instance_storage_config( InstanceId = "string", AssociationId = "string", ResourceType = "CHAT_TRANSCRIPTS"|"CALL_RECORDINGS"|"SCHEDULED_REPORTS"|"MEDIA_STREAMS"|"CONTACT_TRACE_RECORDS"|"AGENT_EVENTS" )