Learn R Programming

paws.customer.engagement (version 0.1.11)

connect_disassociate_lambda_function: This API is in preview release for Amazon Connect and is subject to change

Description

This API is in preview release for Amazon Connect and is subject to change.

Remove the Lambda function from the drop-down options available in the relevant contact flow blocks.

Usage

connect_disassociate_lambda_function(InstanceId, FunctionArn)

Arguments

InstanceId

[required] The identifier of the Amazon Connect instance..

FunctionArn

[required] The Amazon Resource Name (ARN) of the Lambda function being disassociated.

Value

An empty list.

Request syntax

svc$disassociate_lambda_function(
  InstanceId = "string",
  FunctionArn = "string"
)