This API is in preview release for Amazon Connect and is subject to change.
Provides summary information about the AppIntegration associations for the specified Amazon Connect instance.
connect_list_integration_associations(InstanceId, NextToken, MaxResults)[required] The identifier of the Amazon Connect instance.
The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
The maximimum number of results to return per page.
A list with the following syntax:
list(
IntegrationAssociationSummaryList = list(
list(
IntegrationAssociationId = "string",
IntegrationAssociationArn = "string",
InstanceId = "string",
IntegrationType = "EVENT",
IntegrationArn = "string",
SourceApplicationUrl = "string",
SourceApplicationName = "string",
SourceType = "SALESFORCE"|"ZENDESK"
)
),
NextToken = "string"
)
svc$list_integration_associations( InstanceId = "string", NextToken = "string", MaxResults = 123 )