Updates the specified contact flow.
You can also create and update contact flows using the Amazon Connect Flow language.
connect_update_contact_flow_content(InstanceId, ContactFlowId, Content)[required] The identifier of the Amazon Connect instance.
[required] The identifier of the contact flow.
[required] The JSON string that represents contact flow<U+2019>s content. For an example, see Example contact flow in Amazon Connect Flow language in the Amazon Connect Administrator Guide.
An empty list.
svc$update_contact_flow_content( InstanceId = "string", ContactFlowId = "string", Content = "string" )