Instructs Amazon Connect to resume the authentication process. The subsequent actions depend on the request body contents:
See https://www.paws-r-sdk.com/docs/connect_update_participant_authentication/ for full documentation.
connect_update_participant_authentication(
State,
InstanceId,
Code = NULL,
Error = NULL,
ErrorDescription = NULL
)[required] The state query parameter that was provided by Cognito in the
redirectUri. This will also match the state parameter provided in
the AuthenticationUrl from the
GetAuthenticationUrl
response.
[required] The identifier of the Amazon Connect instance. You can find the instance ID in the Amazon Resource Name (ARN) of the instance.
The code query parameter provided by Cognito in the redirectUri.
The error query parameter provided by Cognito in the redirectUri.
The error_description parameter provided by Cognito in the
redirectUri.