This API is in preview release for Amazon Connect and is subject to change.
Updates the name and description of a quick connect. The request accepts the following data in JSON format. At least Name or Description must be provided.
connect_update_quick_connect_name(InstanceId, QuickConnectId, Name,
Description)[required] The identifier of the Amazon Connect instance.
[required] The identifier for the quick connect.
The name of the quick connect.
The description of the quick connect.
An empty list.
svc$update_quick_connect_name( InstanceId = "string", QuickConnectId = "string", Name = "string", Description = "string" )