Updates the attributes of an existing template. The template attributes that can be modified include name, description, layoutConfiguration, requiredFields, and status. At least one of these attributes must not be null. If a null value is provided for a given attribute, that attribute is ignored and its current value is preserved.
See https://www.paws-r-sdk.com/docs/connectcases_update_template/ for full documentation.
connectcases_update_template(
description = NULL,
domainId,
layoutConfiguration = NULL,
name = NULL,
requiredFields = NULL,
status = NULL,
templateId
)A brief description of the template.
[required] The unique identifier of the Cases domain.
Configuration of layouts associated to the template.
The name of the template. It must be unique per domain.
A list of fields that must contain a value for a case to be successfully created with this template.
The status of the template.
[required] A unique identifier for the template.