Get a URL to upload content to a knowledge base. To upload content, first make a PUT request to the returned URL with your file, making sure to include the required headers. Then use create_content to finalize the content creation process or update_content to modify an existing resource. You can only upload content to a knowledge base of type CUSTOM.
See https://www.paws-r-sdk.com/docs/connectwisdomservice_start_content_upload/ for full documentation.
connectwisdomservice_start_content_upload(contentType, knowledgeBaseId)[required] The type of content to upload.
[required] The identifier of the knowledge base. Can be either the ID or the ARN. URLs cannot contain the ARN.