Before calling this API, use create_domain or update_domain to enable identity resolution: set Matching to true.
See https://www.paws-r-sdk.com/docs/customerprofiles_get_matches/ for full documentation.
customerprofiles_get_matches(NextToken = NULL, MaxResults = NULL, DomainName)The token for the next set of results. Use the value returned in the previous response in the next request to retrieve the next set of results.
The maximum number of results to return per page.
[required] The unique name of the domain.