Retrieves information about all the applications that are associated with your Amazon Pinpoint account.
pinpoint_get_apps(PageSize, Token)The maximum number of items to include in each page of a paginated response. This parameter is not supported for application, campaign, and journey metrics.
The NextToken string that specifies which page of results to return in a paginated response.
A list with the following syntax:
list(
ApplicationsResponse = list(
Item = list(
list(
Arn = "string",
Id = "string",
Name = "string",
tags = list(
"string"
)
)
),
NextToken = "string"
)
)
svc$get_apps( PageSize = "string", Token = "string" )