| create_configuration_set | Create a new configuration set |
| create_configuration_set_event_destination | Create a new event destination in a configuration set |
| delete_configuration_set | Deletes an existing configuration set |
| delete_configuration_set_event_destination | Deletes an event destination in a configuration set |
| get_configuration_set_event_destinations | Obtain information about an event destination, including the types of events it reports, the Amazon Resource Name (ARN) of the destination, and the name of the event destination |
| list_configuration_sets | List all of the configuration sets associated with your Amazon Pinpoint account in the current region |
| send_voice_message | Create a new voice message and send it to a recipient's phone number |
| update_configuration_set_event_destination | Update an event destination in a configuration set |