Describes the specified opt-out list or all opt-out lists in your account.
See https://www.paws-r-sdk.com/docs/pinpointsmsvoicev2_describe_opt_out_lists/ for full documentation.
pinpointsmsvoicev2_describe_opt_out_lists(
OptOutListNames = NULL,
NextToken = NULL,
MaxResults = NULL,
Owner = NULL
)The OptOutLists to show the details of. This is an array of strings that can be either the OptOutListName or OptOutListArn.
If you are using a shared AWS End User Messaging SMS and Voice resource then you must use the full Amazon Resource Name(ARN).
The token to be used for the next set of paginated results. You don't need to supply a value for this field in the initial request.
The maximum number of results to return per each request.
Use SELF to filter the list of Opt-Out List to ones your account owns
or use SHARED to filter on Opt-Out List shared with your account. The
Owner and OptOutListNames parameters can't be used at the same time.