Learn R Programming

paws.customer.engagement (version 0.1.11)

ses_create_configuration_set: Creates a configuration set

Description

Creates a configuration set.

Configuration sets enable you to publish email sending events. For information about using configuration sets, see the Amazon SES Developer Guide.

You can execute this operation no more than once per second.

Usage

ses_create_configuration_set(ConfigurationSet)

Arguments

ConfigurationSet

[required] A data structure that contains the name of the configuration set.

Value

An empty list.

Request syntax

svc$create_configuration_set(
  ConfigurationSet = list(
    Name = "string"
  )
)