Creates a configuration set event destination.
See https://www.paws-r-sdk.com/docs/ses_create_configuration_set_event_destination/ for full documentation.
ses_create_configuration_set_event_destination(
ConfigurationSetName,
EventDestination
)[required] The name of the configuration set that the event destination should be associated with.
[required] An object that describes the AWS service that email sending event information will be published to.