Learn R Programming

paws.customer.engagement (version 0.3.0)

ses_create_receipt_rule: Creates a receipt rule

Description

Creates a receipt rule.

See https://www.paws-r-sdk.com/docs/ses_create_receipt_rule/ for full documentation.

Usage

ses_create_receipt_rule(RuleSetName, After = NULL, Rule)

Arguments

RuleSetName

[required] The name of the rule set that the receipt rule will be added to.

After

The name of an existing rule after which the new rule will be placed. If this parameter is null, the new rule will be inserted at the beginning of the rule list.

Rule

[required] A data structure that contains the specified rule's name, actions, recipients, domains, enabled status, scan status, and TLS policy.