powered by
Creates an empty receipt rule set.
For information about setting up receipt rule sets, see the Amazon SES Developer Guide.
You can execute this operation no more than once per second.
ses_create_receipt_rule_set(RuleSetName)
[required] The name of the rule set to create. The name must:
This value can only contain ASCII letters (a-z, A-Z), numbers (0-9), underscores (_), or dashes (-).
Start and end with a letter or number.
Contain less than 64 characters.
An empty list.
svc$create_receipt_rule_set( RuleSetName = "string" )
# NOT RUN { # The following example creates an empty receipt rule set: svc$create_receipt_rule_set( RuleSetName = "MyRuleSet" ) # } # NOT RUN { # }
Run the code above in your browser using DataLab