Learn R Programming

paws.customer.engagement (version 0.3.0)

ses_create_template: Creates an email template

Description

Creates an email template. Email templates enable you to send personalized email to one or more destinations in a single API operation. For more information, see the Amazon SES Developer Guide.

See https://www.paws-r-sdk.com/docs/ses_create_template/ for full documentation.

Usage

ses_create_template(Template)

Arguments

Template

[required] The content of the email, composed of a subject line, an HTML part, and a text-only part.