Learn R Programming

paws.customer.engagement (version 0.1.11)

ses_delete_receipt_rule_set: Deletes the specified receipt rule set and all of the receipt rules it contains

Description

Deletes the specified receipt rule set and all of the receipt rules it contains.

The currently active rule set cannot be deleted.

For information about managing receipt rule sets, see the Amazon SES Developer Guide.

You can execute this operation no more than once per second.

Usage

ses_delete_receipt_rule_set(RuleSetName)

Arguments

RuleSetName

[required] The name of the receipt rule set to delete.

Value

An empty list.

Request syntax

svc$delete_receipt_rule_set(
  RuleSetName = "string"
)

Examples

Run this code
# NOT RUN {
# The following example deletes a receipt rule set:
svc$delete_receipt_rule_set(
  RuleSetName = "MyRuleSet"
)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab