powered by
Returns the email sending status of the Amazon SES account for the current region.
You can execute this operation no more than once per second.
ses_get_account_sending_enabled()
A list with the following syntax:
list( Enabled = TRUE|FALSE )
# NOT RUN { # The following example returns if sending status for an account is # enabled. (true / false): svc$get_account_sending_enabled() # } # NOT RUN { # }
Run the code above in your browser using DataLab