Returns a list containing all of the identities (email addresses and domains) for your AWS account in the current AWS Region, regardless of verification status.
See https://www.paws-r-sdk.com/docs/ses_list_identities/ for full documentation.
ses_list_identities(IdentityType = NULL, NextToken = NULL, MaxItems = NULL)The type of the identities to list. Possible values are "EmailAddress" and "Domain". If this parameter is omitted, then all identities will be listed.
The token to use for pagination.
The maximum number of identities per page. Possible values are 1-1000 inclusive.