Lists the receipt rule sets that exist under your AWS account in the current AWS Region. If there are additional receipt rule sets to be retrieved, you will receive a NextToken that you can provide to the next call to list_receipt_rule_sets to retrieve the additional entries.
See https://www.paws-r-sdk.com/docs/ses_list_receipt_rule_sets/ for full documentation.
ses_list_receipt_rule_sets(NextToken = NULL)A token returned from a previous call to
list_receipt_rule_sets to indicate the
position in the receipt rule set list.