ses_reorder_receipt_rule_set: Reorders the receipt rules within a receipt rule set
Usage
ses_reorder_receipt_rule_set(RuleSetName, RuleNames)
Arguments
- RuleSetName
[required] The name of the receipt rule set to reorder.
- RuleNames
[required] A list of the specified receipt rule set's receipt rules in the order
that you want to put them.