Given an identity (an email address or a domain), enables or disables whether Amazon SES forwards bounce and complaint notifications as email. Feedback forwarding can only be disabled when Amazon Simple Notification Service (Amazon SNS) topics are specified for both bounces and complaints.
See https://www.paws-r-sdk.com/docs/ses_set_identity_feedback_forwarding_enabled/ for full documentation.
ses_set_identity_feedback_forwarding_enabled(Identity, ForwardingEnabled)[required] The identity for which to set bounce and complaint notification
forwarding. Examples: user@example.com, example.com.
[required] Sets whether Amazon SES will forward bounce and complaint notifications
as email. true specifies that Amazon SES will forward bounce and
complaint notifications as email, in addition to any Amazon SNS topic
publishing otherwise specified. false specifies that Amazon SES will
publish bounce and complaint notifications only through Amazon SNS. This
value can only be set to false when Amazon SNS topics are set for both
Bounce and Complaint notification types.