Enables or disables email sending across your entire Amazon SES account in the current AWS Region. You can use this operation in conjunction with Amazon CloudWatch alarms to temporarily pause email sending across your Amazon SES account in a given AWS Region when reputation metrics (such as your bounce or complaint rates) reach certain thresholds.
See https://www.paws-r-sdk.com/docs/ses_update_account_sending_enabled/ for full documentation.
ses_update_account_sending_enabled(Enabled = NULL)Describes whether email sending is enabled or disabled for your Amazon SES account in the current AWS Region.