Learn R Programming

paws.customer.engagement (version 0.1.11)

ses_verify_domain_identity: Adds a domain to the list of identities for your Amazon SES account in the current AWS Region and attempts to verify it

Description

Adds a domain to the list of identities for your Amazon SES account in the current AWS Region and attempts to verify it. For more information about verifying domains, see Verifying Email Addresses and Domains in the Amazon SES Developer Guide.

You can execute this operation no more than once per second.

Usage

ses_verify_domain_identity(Domain)

Arguments

Domain

[required] The domain to be verified.

Value

A list with the following syntax:

list(
  VerificationToken = "string"
)

Request syntax

svc$verify_domain_identity(
  Domain = "string"
)

Examples

Run this code
# NOT RUN {
# The following example starts the domain verification process with Amazon
# SES:
svc$verify_domain_identity(
  Domain = "example.com"
)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab