Lists all of the export jobs.
See https://www.paws-r-sdk.com/docs/sesv2_list_export_jobs/ for full documentation.
sesv2_list_export_jobs(
NextToken = NULL,
PageSize = NULL,
ExportSourceType = NULL,
JobStatus = NULL
)The pagination token returned from a previous call to
list_export_jobs to indicate the position in
the list of export jobs.
Maximum number of export jobs to return at once. Use this parameter to
paginate results. If additional export jobs exist beyond the specified
limit, the NextToken element is sent in the response. Use the
NextToken value in subsequent calls to
list_export_jobs to retrieve additional
export jobs.
A value used to list export jobs that have a certain ExportSourceType.
A value used to list export jobs that have a certain JobStatus.