Enable or disable email sending for messages that use a particular configuration set in a specific Amazon Web Services Region.
See https://www.paws-r-sdk.com/docs/sesv2_put_configuration_set_sending_options/ for full documentation.
sesv2_put_configuration_set_sending_options(
ConfigurationSetName,
SendingEnabled = NULL
)[required] The name of the configuration set to enable or disable email sending for.
If true, email sending is enabled for the configuration set. If
false, email sending is disabled for the configuration set.