Creates the participant's connection.
See https://www.paws-r-sdk.com/docs/connectparticipant_create_participant_connection/ for full documentation.
connectparticipant_create_participant_connection(
Type = NULL,
ParticipantToken,
ConnectParticipant = NULL
)Type of connection information required. This can be omitted if
ConnectParticipant is true.
[required] This is a header parameter.
The ParticipantToken as obtained from StartChatContact API response.
Amazon Connect Participant is used to mark the participant as connected for customer participant in message streaming, as well as for agent or manager participant in non-streaming chats.