Deletes the specified sending authorization policy for the given identity (an email address or a domain). This API returns successfully even if a policy with the specified name does not exist.
See https://www.paws-r-sdk.com/docs/ses_delete_identity_policy/ for full documentation.
ses_delete_identity_policy(Identity, PolicyName)[required] The identity that is associated with the policy that you want to delete.
You can specify the identity by using its name or by using its Amazon
Resource Name (ARN). Examples: user@example.com, example.com,
arn:aws:ses:us-east-1:123456789012:identity/example.com.
To successfully call this API, you must own the identity.
[required] The name of the policy to be deleted.