Returns a list of sending authorization policies that are attached to the given identity (an email address or a domain). This API returns only a list. If you want the actual policy content, you can use get_identity_policies.
See https://www.paws-r-sdk.com/docs/ses_list_identity_policies/ for full documentation.
ses_list_identity_policies(Identity)[required] The identity that is associated with the policy for which the policies
will be listed. You can specify an identity by using its name or by
using its Amazon Resource Name (ARN). Examples: user@example.com,
example.com,
arn:aws:ses:us-east-1:123456789012:identity/example.com.
To successfully call this API, you must own the identity.