Learn R Programming

paws.customer.engagement (version 0.1.11)

ses_list_receipt_rule_sets: Lists the receipt rule sets that exist under your AWS account in the current AWS Region

Description

Lists the receipt rule sets that exist under your AWS account in the current AWS Region. If there are additional receipt rule sets to be retrieved, you will receive a NextToken that you can provide to the next call to list_receipt_rule_sets to retrieve the additional entries.

For information about managing receipt rule sets, see the Amazon SES Developer Guide.

You can execute this operation no more than once per second.

Usage

ses_list_receipt_rule_sets(NextToken)

Arguments

NextToken

A token returned from a previous call to list_receipt_rule_sets to indicate the position in the receipt rule set list.

Value

A list with the following syntax:

list(
  RuleSets = list(
    list(
      Name = "string",
      CreatedTimestamp = as.POSIXct(
        "2015-01-01"
      )
    )
  ),
  NextToken = "string"
)

Request syntax

svc$list_receipt_rule_sets(
  NextToken = "string"
)

Examples

Run this code
# NOT RUN {
# The following example lists the receipt rule sets that exist under an
# AWS account:
svc$list_receipt_rule_sets(
  NextToken = ""
)
# }
# NOT RUN {
# }

Run the code above in your browser using DataLab