ses_list_receipt_rule_sets: Lists the receipt rule sets that exist under your AWS account in the
current AWS Region
Description
Lists the receipt rule sets that exist under your AWS account in the
current AWS Region. If there are additional receipt rule sets to be
retrieved, you will receive a NextToken that you can provide to the
next call to list_receipt_rule_sets to
retrieve the additional entries.
# NOT RUN {# The following example lists the receipt rule sets that exist under an# AWS account:svc$list_receipt_rule_sets(
NextToken = "")
# }# NOT RUN {# }