Lists the email templates present in your Amazon SES account in the current AWS Region.
See https://www.paws-r-sdk.com/docs/ses_list_templates/ for full documentation.
ses_list_templates(NextToken = NULL, MaxItems = NULL)A token returned from a previous call to
list_templates to indicate the position in the
list of email templates.
The maximum number of templates to return. This value must be at least 1 and less than or equal to 10. If you do not specify a value, or if you specify a value less than 1 or greater than 10, the operation will return up to 10 results.